/**
 * Copyright 2006 Joseph M. Ferner
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *    
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.fernsroth.easyio;

import java.io.IOException;
import java.io.InputStream;

/**
 * counts the number of bytes read.
 * @author Joseph M. Ferner (Near Infinity Corporation)
 */
public class CountingNullInputStream extends InputStream {

    /**
     * the number of bytes read from this stream.
     */
    private int count = 0;

    /**
     * {@inheritDoc}
     */
    @Override
    public int read() throws IOException {
        this.count++;
        return 0;
    }

    /**
     * gets the count.
     * @return the count
     */
    public int getCount() {
        return this.count;
    }

}
