/**
 * Copyright 2006 Joseph M. Ferner
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *    
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.fernsroth.easyio;

import java.lang.annotation.Annotation;
import java.lang.reflect.Field;
import java.util.HashMap;
import java.util.Map;

import com.fernsroth.easyio.field.FieldINT64;
import com.fernsroth.easyio.field.FieldUINT16;
import com.fernsroth.easyio.field.FieldUINT32;
import com.fernsroth.easyio.field.FieldUINT64;
import com.fernsroth.easyio.field.FieldUINT8;
import com.fernsroth.easyio.field.handler.FieldINT64Handler;
import com.fernsroth.easyio.field.handler.FieldUINT16Handler;
import com.fernsroth.easyio.field.handler.FieldUINT32Handler;
import com.fernsroth.easyio.field.handler.FieldUINT64Handler;
import com.fernsroth.easyio.field.handler.FieldUINT8Handler;

/**
 * 
 * @author Joseph M. Ferner (Near Infinity Corporation)
 */
public class DefaultFieldHandlerRegistry implements FieldHandlerRegistry {

    /**
     * the instance.
     */
    private static DefaultFieldHandlerRegistry instance;

    /**
     * the registry.
     */
    private Map<Class<? extends Annotation>, FieldHandler> registry = new HashMap<Class<? extends Annotation>, FieldHandler>();

    /**
     * gets an instance of the this class.
     * @return the instance.
     */
    public static FieldHandlerRegistry getInstance() {
        if (instance == null) {
            instance = new DefaultFieldHandlerRegistry();
            instance.register(FieldUINT8.class, new FieldUINT8Handler());
            instance.register(FieldUINT16.class, new FieldUINT16Handler());
            instance.register(FieldUINT32.class, new FieldUINT32Handler());
            instance.register(FieldINT64.class, new FieldINT64Handler());
            instance.register(FieldUINT64.class, new FieldUINT64Handler());
        }
        return instance;
    }

    /**
     * @param an the annotation to register.
     * @param handler the handler.
     */
    public void register(Class<? extends Annotation> an, FieldHandler handler) {
        this.registry.put(an, handler);
    }

    /**
     * {@inheritDoc}
     */
    public FieldHandler lookup(Object obj, Field field) {
        for (Annotation an : field.getDeclaredAnnotations()) {
            Class<? extends Annotation> anType = an.annotationType();
            FieldHandler handler = this.registry.get(anType);
            if (handler != null) {
                return handler;
            }
        }

        for (Annotation an : field.getAnnotations()) {
            Class<? extends Annotation> anType = an.annotationType();
            FieldHandler handler = this.registry.get(anType);
            if (handler != null) {
                return handler;
            }
        }
        return null;
    }
}
