/**
 * Copyright 2006 Joseph M. Ferner
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *    
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.fernsroth.easyio;

import java.io.IOException;
import java.lang.reflect.Field;
import java.util.Queue;

import com.fernsroth.easyio.exception.EasyIOException;

/**
 * 
 * @author Joseph M. Ferner (Near Infinity Corporation)
 */
public interface FieldHandler {

    /**
     * reads a field into an object.
     * It is the responsibility of this function to remove read fields from the
     * fieldsQueue.
     * @param in the input stream to read from.
     * @param obj the object to populate.
     * @param fieldsQueue the queue of all fields (field, is head of queue).
     * @throws EasyIOException 
     * @throws IOException 
     */
    void read(EasyIOInputStream in, Object obj, Queue<Field> fieldsQueue)
            throws EasyIOException, IOException;

    /**
     * writes a field into an output stream.
     * It is the responsibility of this function to remove written fields from the
     * fieldsQueue.
     * @param out the output stream to write the field to.
     * @param obj the object to read from.
     * @param fieldsQueue the queue of fields to read (field, is head of queue).
     * @throws EasyIOException 
     * @throws IOException 
     */
    void write(EasyIOOutputStream out, Object obj, Queue<Field> fieldsQueue)
            throws EasyIOException, IOException;

}
