/**
 * Copyright 2006 Joseph M. Ferner
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *    
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.fernsroth.easyio;

import java.io.IOException;

/**
 * 
 * @author Joseph M. Ferner (Near Infinity Corporation)
 */
public interface IRandomAccessSource extends IInputStream, IOutputStream {
    /**
     * sets the location.
     * @param newLocation the location.
     * @throws IOException 
     */
    void seek(long newLocation) throws IOException;

    /**
     * gets the current location.
     * @return the current location.
     * @throws IOException 
     */
    long getFilePointer() throws IOException;

    /**
     * sets the length.
     * @param length the length.
     * @throws IOException
     */
    void setLength(long length) throws IOException;

    /**
     * gets the length.
     * @return the length.
     * @throws IOException
     */
    long length() throws IOException;
}
