/**
 * Copyright 2006 Joseph M. Ferner
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *    
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.fernsroth.easyio;

import java.io.IOException;

/**
 * 
 * @author Joseph M. Ferner (Near Infinity Corporation)
 */
public class RandomAccessByteArray implements IRandomAccessSource {

    /**
     * the data.
     */
    private byte[] data;

    /**
     * the location. 
     */
    private long loc;

    /**
     * constructor.
     * @param data the data.
     */
    public RandomAccessByteArray(byte[] data) {
        this.data = data;
        this.loc = 0;
    }

    /**
     * {@inheritDoc}
     */
    public void seek(long newLocation) {
        this.loc = newLocation;
    }

    /**
     * {@inheritDoc}
     */
    public long getFilePointer() {
        return this.loc;
    }

    /**
     * {@inheritDoc}
     */
    public void write(int b) {
        this.data[(int) this.loc++] = (byte) b;
    }

    /**
     * {@inheritDoc}
     */
    public void write(byte[] buffer) {
        write(buffer, 0, buffer.length);
    }

    /**
     * {@inheritDoc}
     */
    public void write(byte[] buffer, int start, int length) {
        for (int i = start; i < start + length; i++) {
            write(buffer[i]);
        }
    }

    /**
     * {@inheritDoc}
     */
    public int read() {
        return this.data[(int) this.loc++];
    }

    /**
     * {@inheritDoc}
     */
    public int read(byte[] buffer, int off, int len) {
        for (int i = 0; i < len; i++) {
            buffer[i + off] = this.data[(int) this.loc++];
        }
        return len;
    }

    /**
     * {@inheritDoc}
     */
    public int read(byte[] buffer) {
        return read(buffer, 0, buffer.length);
    }

    /**
     * {@inheritDoc}
     */
    public void setLength(long length) throws IOException {
        // TODO should we resize the array?
    }

    /**
     * {@inheritDoc}
     */
    public long length() throws IOException {
        return this.data.length;
    }
}
