/**
 * Copyright 2006 Joseph M. Ferner
 * 
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *    
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.fernsroth.easyio;

import java.io.IOException;
import java.io.InputStream;
import java.io.RandomAccessFile;

/**
 * 
 * @author Joseph M. Ferner (Near Infinity Corporation)
 */
public class RandomAccessFileInputStreamAdaptor extends InputStream {

    /**
     * the random access file.
     */
    private RandomAccessFile raf;

    /**
     * constructor.
     * @param raf the random access file.
     */
    public RandomAccessFileInputStreamAdaptor(RandomAccessFile raf) {
        this.raf = raf;
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int read() throws IOException {
        return this.raf.read();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int read(byte[] b, int off, int len) throws IOException {
        return this.raf.read(b, off, len);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public int read(byte[] b) throws IOException {
        return this.raf.read(b);
    }

}
